@@ -16,6 +16,7 @@ use Doctrine\Persistence\ManagerRegistry;
 use Doctrine\Persistence\Mapping\ClassMetadata;
 use Doctrine\Persistence\ObjectManager;
 use Doctrine\Persistence\ObjectRepository;
+use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\MockObject\MockObject;
 use PHPUnit\Framework\TestCase;
 use Symfony\Bridge\Doctrine\ArgumentResolver\EntityValueResolver;
@@ -24,13 +25,14 @@ use Symfony\Component\ExpressionLanguage\ExpressionLanguage;
 use Symfony\Component\ExpressionLanguage\SyntaxError;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\ControllerMetadata\ArgumentMetadata;
+use Symfony\Component\HttpKernel\Exception\NearMissValueResolverException;
 use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
 
 class EntityValueResolverTest extends TestCase
 {
     public function testResolveWithoutClass()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -42,7 +44,7 @@ class EntityValueResolverTest extends TestCase
 
     public function testResolveWithoutAttribute()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry, null, new MapEntity(disabled: true));
 
@@ -65,49 +67,45 @@ class EntityValueResolverTest extends TestCase
 
     public function testResolveWithNoIdAndDataOptional()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
         $request = new Request();
         $argument = $this->createArgument(null, new MapEntity(), 'arg', true);
 
+        $this->expectException(NearMissValueResolverException::class);
+        $this->expectExceptionMessage('Cannot find mapping for "stdClass": declare one using either the #[MapEntity] attribute or mapped route parameters.');
+
         $this->assertSame([], $resolver->resolve($request, $argument));
     }
 
     public function testResolveWithStripNulls()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
         $request = new Request();
         $request->attributes->set('arg', null);
-        $argument = $this->createArgument('stdClass', new MapEntity(stripNull: true), 'arg', true);
+        $argument = $this->createArgument('stdClass', new MapEntity(mapping: ['arg'], stripNull: true), 'arg', true);
 
-        $metadata = $this->getMockBuilder(ClassMetadata::class)->getMock();
-        $metadata->expects($this->once())
-            ->method('hasField')
-            ->with('arg')
-            ->willReturn(true);
-
-        $manager->expects($this->once())
-            ->method('getClassMetadata')
-            ->with('stdClass')
-            ->willReturn($metadata);
+        $manager->expects($this->never())
+            ->method('getClassMetadata');
 
         $manager->expects($this->never())
             ->method('getRepository');
 
+        $this->expectException(NearMissValueResolverException::class);
+        $this->expectExceptionMessage('Cannot find mapping for "stdClass": declare one using either the #[MapEntity] attribute or mapped route parameters.');
+
         $this->assertSame([], $resolver->resolve($request, $argument));
     }
 
-    /**
-     * @dataProvider idsProvider
-     */
+    #[DataProvider('idsProvider')]
     public function testResolveWithId(string|int $id)
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -116,7 +114,7 @@ class EntityValueResolverTest extends TestCase
 
         $argument = $this->createArgument('stdClass', new MapEntity(id: 'id'));
 
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         $repository->expects($this->once())
             ->method('find')
             ->with($id)
@@ -130,16 +128,50 @@ class EntityValueResolverTest extends TestCase
         $this->assertSame([$object], $resolver->resolve($request, $argument));
     }
 
-    public function testResolveWithNullId()
+    #[DataProvider('idsProvider')]
+    public function testResolveWithIdAndTypeAlias(string|int $id)
     {
         $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
         $registry = $this->createRegistry($manager);
+        $resolver = new EntityValueResolver(
+            $registry,
+            null,
+            new MapEntity(),
+            // Using \Throwable because it is an interface
+            ['Throwable' => 'stdClass'],
+        );
+
+        $request = new Request();
+        $request->attributes->set('id', $id);
+
+        $argument = $this->createArgument('Throwable', $mapEntity = new MapEntity(id: 'id'));
+
+        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository->expects($this->once())
+            ->method('find')
+            ->with($id)
+            ->willReturn($object = new \stdClass());
+
+        $manager->expects($this->once())
+            ->method('getRepository')
+            ->with('stdClass')
+            ->willReturn($repository);
+
+        $this->assertSame([$object], $resolver->resolve($request, $argument));
+        // Ensure the original MapEntity object was not updated
+        $this->assertNull($mapEntity->class);
+    }
+
+    public function testResolveWithNullId()
+    {
+        $manager = $this->createMock(ObjectManager::class);
+        $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
         $request = new Request();
         $request->attributes->set('id', null);
 
-        $argument = $this->createArgument(isNullable: true);
+        $argument = $this->createArgument(isNullable: true, entity: new MapEntity(id: 'id'));
 
         $this->assertSame([null], $resolver->resolve($request, $argument));
     }
@@ -153,23 +185,23 @@ class EntityValueResolverTest extends TestCase
         $request = new Request();
         $request->attributes->set('nullValue', null);
 
-        $argument = $this->createArgument(entity: new MapEntity(id: ['nullValue']), isNullable: true,);
+        $argument = $this->createArgument(entity: new MapEntity(id: ['nullValue']), isNullable: true);
 
         $this->assertSame([null], $resolver->resolve($request, $argument));
     }
 
     public function testResolveWithConversionFailedException()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
         $request = new Request();
         $request->attributes->set('id', 'test');
 
-        $argument = $this->createArgument('stdClass', new MapEntity(id: 'id'));
+        $argument = $this->createArgument('stdClass', new MapEntity(id: 'id', message: 'Test'));
 
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         $repository->expects($this->once())
             ->method('find')
             ->with('test')
@@ -181,13 +213,14 @@ class EntityValueResolverTest extends TestCase
             ->willReturn($repository);
 
         $this->expectException(NotFoundHttpException::class);
+        $this->expectExceptionMessage('Test');
 
         $resolver->resolve($request, $argument);
     }
 
     public function testUsedProperIdentifier()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -210,7 +243,7 @@ class EntityValueResolverTest extends TestCase
 
     public function testResolveGuessOptional()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -219,20 +252,19 @@ class EntityValueResolverTest extends TestCase
 
         $argument = $this->createArgument('stdClass', new MapEntity(), 'arg', true);
 
-        $metadata = $this->getMockBuilder(ClassMetadata::class)->getMock();
-        $manager->expects($this->once())
-            ->method('getClassMetadata')
-            ->with('stdClass')
-            ->willReturn($metadata);
-
+        $metadata = $this->createMock(ClassMetadata::class);
+        $manager->expects($this->never())->method('getClassMetadata');
         $manager->expects($this->never())->method('getRepository');
 
+        $this->expectException(NearMissValueResolverException::class);
+        $this->expectExceptionMessage('Cannot find mapping for "stdClass": declare one using either the #[MapEntity] attribute or mapped route parameters.');
+
         $this->assertSame([], $resolver->resolve($request, $argument));
     }
 
     public function testResolveWithMappingAndExclude()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -245,18 +277,10 @@ class EntityValueResolverTest extends TestCase
             new MapEntity(mapping: ['foo' => 'Foo'], exclude: ['bar'])
         );
 
-        $metadata = $this->getMockBuilder(ClassMetadata::class)->getMock();
-        $metadata->expects($this->once())
-            ->method('hasField')
-            ->with('Foo')
-            ->willReturn(true);
+        $manager->expects($this->never())
+            ->method('getClassMetadata');
 
-        $manager->expects($this->once())
-            ->method('getClassMetadata')
-            ->with('stdClass')
-            ->willReturn($metadata);
-
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         $repository->expects($this->once())
             ->method('findOneBy')
             ->with(['Foo' => 1])
@@ -270,9 +294,45 @@ class EntityValueResolverTest extends TestCase
         $this->assertSame([$object], $resolver->resolve($request, $argument));
     }
 
+    public function testResolveWithRouteMapping()
+    {
+        $manager = $this->createMock(ObjectManager::class);
+        $registry = $this->createRegistry($manager);
+        $resolver = new EntityValueResolver($registry);
+
+        $request = new Request();
+        $request->attributes->set('conference', 'vienna-2024');
+        $request->attributes->set('article', ['title' => 'foo']);
+        $request->attributes->set('_route_mapping', ['slug' => 'conference']);
+
+        $argument1 = $this->createArgument('Conference', new MapEntity('Conference'), 'conference');
+        $argument2 = $this->createArgument('Article', new MapEntity('Article'), 'article');
+
+        $manager->expects($this->never())
+            ->method('getClassMetadata');
+
+        $conference = new \stdClass();
+        $article = new \stdClass();
+
+        $repository = $this->createMock(ObjectRepository::class);
+        $repository->expects($this->any())
+            ->method('findOneBy')
+            ->willReturnCallback(static fn ($v) => match ($v) {
+                ['slug' => 'vienna-2024'] => $conference,
+                ['title' => 'foo'] => $article,
+            });
+
+        $manager->expects($this->any())
+            ->method('getRepository')
+            ->willReturn($repository);
+
+        $this->assertSame([$conference], $resolver->resolve($request, $argument1));
+        $this->assertSame([$article], $resolver->resolve($request, $argument2));
+    }
+
     public function testExceptionWithExpressionIfNoLanguageAvailable()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -290,9 +350,9 @@ class EntityValueResolverTest extends TestCase
 
     public function testExpressionFailureReturns404()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
-        $language = $this->getMockBuilder(ExpressionLanguage::class)->getMock();
+        $language = $this->createMock(ExpressionLanguage::class);
         $resolver = new EntityValueResolver($registry, $language);
 
         $this->expectException(NotFoundHttpException::class);
@@ -304,13 +364,14 @@ class EntityValueResolverTest extends TestCase
             'arg1'
         );
 
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         // find should not be attempted on this repository as a fallback
         $repository->expects($this->never())
             ->method('find');
 
         $manager->expects($this->once())
             ->method('getRepository')
+            ->with(\stdClass::class)
             ->willReturn($repository);
 
         $language->expects($this->once())
@@ -322,9 +383,9 @@ class EntityValueResolverTest extends TestCase
 
     public function testExpressionMapsToArgument()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
-        $language = $this->getMockBuilder(ExpressionLanguage::class)->getMock();
+        $language = $this->createMock(ExpressionLanguage::class);
         $resolver = new EntityValueResolver($registry, $language);
 
         $request = new Request();
@@ -335,13 +396,14 @@ class EntityValueResolverTest extends TestCase
             'arg1'
         );
 
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         // find should not be attempted on this repository as a fallback
         $repository->expects($this->never())
             ->method('find');
 
         $manager->expects($this->once())
             ->method('getRepository')
+            ->with(\stdClass::class)
             ->willReturn($repository);
 
         $language->expects($this->once())
@@ -356,11 +418,53 @@ class EntityValueResolverTest extends TestCase
         $this->assertSame([$object], $resolver->resolve($request, $argument));
     }
 
+    public function testExpressionMapsToIterableArgument()
+    {
+        $manager = $this->createMock(ObjectManager::class);
+        $registry = $this->createRegistry($manager);
+        $language = $this->createMock(ExpressionLanguage::class);
+        $resolver = new EntityValueResolver($registry, $language);
+
+        $request = new Request();
+        $request->attributes->set('id', 5);
+        $request->query->set('sort', 'ASC');
+        $request->query->set('limit', 10);
+        $argument = $this->createArgument(
+            'iterable',
+            new MapEntity(
+                class: \stdClass::class,
+                expr: $expr = 'repository.findBy({"author": id}, {"createdAt": request.query.get("sort", "DESC")}, request.query.getInt("limit", 10))',
+            ),
+            'arg1',
+        );
+
+        $repository = $this->createMock(ObjectRepository::class);
+        // find should not be attempted on this repository as a fallback
+        $repository->expects($this->never())
+            ->method('find');
+
+        $manager->expects($this->once())
+            ->method('getRepository')
+            ->with(\stdClass::class)
+            ->willReturn($repository);
+
+        $language->expects($this->once())
+            ->method('evaluate')
+            ->with($expr, [
+                'repository' => $repository,
+                'request' => $request,
+                'id' => 5,
+            ])
+            ->willReturn($objects = [new \stdClass(), new \stdClass()]);
+
+        $this->assertSame([$objects], $resolver->resolve($request, $argument));
+    }
+
     public function testExpressionSyntaxErrorThrowsException()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
-        $language = $this->getMockBuilder(ExpressionLanguage::class)->getMock();
+        $language = $this->createMock(ExpressionLanguage::class);
         $resolver = new EntityValueResolver($registry, $language);
 
         $request = new Request();
@@ -370,13 +474,14 @@ class EntityValueResolverTest extends TestCase
             'arg1'
         );
 
-        $repository = $this->getMockBuilder(ObjectRepository::class)->getMock();
+        $repository = $this->createMock(ObjectRepository::class);
         // find should not be attempted on this repository as a fallback
         $repository->expects($this->never())
             ->method('find');
 
         $manager->expects($this->once())
             ->method('getRepository')
+            ->with(\stdClass::class)
             ->willReturn($repository);
 
         $language->expects($this->once())
@@ -390,7 +495,7 @@ class EntityValueResolverTest extends TestCase
 
     public function testAlreadyResolved()
     {
-        $manager = $this->getMockBuilder(ObjectManager::class)->getMock();
+        $manager = $this->createMock(ObjectManager::class);
         $registry = $this->createRegistry($manager);
         $resolver = new EntityValueResolver($registry);
 
@@ -409,7 +514,7 @@ class EntityValueResolverTest extends TestCase
 
     private function createRegistry(?ObjectManager $manager = null): ManagerRegistry&MockObject
     {
-        $registry = $this->getMockBuilder(ManagerRegistry::class)->getMock();
+        $registry = $this->createMock(ManagerRegistry::class);
 
         $registry->expects($this->any())
             ->method('getManagerForClass')
@@ -422,7 +527,6 @@ class EntityValueResolverTest extends TestCase
             $registry->method('getManager')->willReturn($manager);
         }
 
-
         return $registry;
     }
 }
