@@ -1,13 +1,6 @@
 <?php
 
-use Symfony\Bundle\FrameworkBundle\Tests\Fixtures\Messenger\BarMessage;
-use Symfony\Bundle\FrameworkBundle\Tests\Fixtures\Messenger\FooMessage;
-
 $container->loadFromExtension('framework', [
-    'annotations' => false,
-    'http_method_override' => false,
-    'handle_all_throwables' => true,
-    'php_errors' => ['log' => true],
     'mailer' => [
         'dsn' => 'smtp://example.com',
     ],
@@ -18,10 +11,10 @@ $container->loadFromExtension('framework', [
         'enabled' => true,
         'notification_on_failed_messages' => true,
         'chatter_transports' => [
-            'slack' => 'null'
+            'slack' => 'null',
         ],
         'texter_transports' => [
-            'twilio' => 'null'
+            'twilio' => 'null',
         ],
         'channel_policy' => [
             'low' => ['slack'],
@@ -29,7 +22,7 @@ $container->loadFromExtension('framework', [
         ],
         'admin_recipients' => [
             ['email' => 'test@test.de', 'phone' => '+490815',],
-        ]
+        ],
     ],
     'scheduler' => false,
 ]);
