@@ -7,6 +7,7 @@ return [
         'Africa/Addis_Ababa' => 'Doğu Afrika Saati (Addis Ababa)',
         'Africa/Algiers' => 'Orta Avrupa Saati (Cezayir)',
         'Africa/Asmera' => 'Doğu Afrika Saati (Asmara)',
+        'Africa/Asmara' => 'Doğu Afrika Saati (Asmara)',
         'Africa/Bamako' => 'Greenwich Ortalama Saati (Bamako)',
         'Africa/Bangui' => 'Batı Afrika Saati (Bangui)',
         'Africa/Banjul' => 'Greenwich Ortalama Saati (Banjul)',
@@ -34,7 +35,7 @@ return [
         'Africa/Kinshasa' => 'Batı Afrika Saati (Kinşasa)',
         'Africa/Lagos' => 'Batı Afrika Saati (Lagos)',
         'Africa/Libreville' => 'Batı Afrika Saati (Librevil)',
-        'Africa/Lome' => 'Greenwich Ortalama Saati (Lome)',
+        'Africa/Lome' => 'Greenwich Ortalama Saati (Lomé)',
         'Africa/Luanda' => 'Batı Afrika Saati (Luanda)',
         'Africa/Lubumbashi' => 'Orta Afrika Saati (Lubumbashi)',
         'Africa/Lusaka' => 'Orta Afrika Saati (Lusaka)',
@@ -45,12 +46,12 @@ return [
         'Africa/Mogadishu' => 'Doğu Afrika Saati (Mogadişu)',
         'Africa/Monrovia' => 'Greenwich Ortalama Saati (Monrovia)',
         'Africa/Nairobi' => 'Doğu Afrika Saati (Nairobi)',
-        'Africa/Ndjamena' => 'Batı Afrika Saati (Ndjamena)',
+        'Africa/Ndjamena' => 'Batı Afrika Saati (N’Djamena)',
         'Africa/Niamey' => 'Batı Afrika Saati (Niamey)',
         'Africa/Nouakchott' => 'Greenwich Ortalama Saati (Nouakchott)',
         'Africa/Ouagadougou' => 'Greenwich Ortalama Saati (Ouagadougou)',
         'Africa/Porto-Novo' => 'Batı Afrika Saati (Porto-Novo)',
-        'Africa/Sao_Tome' => 'Greenwich Ortalama Saati (Sao Tome)',
+        'Africa/Sao_Tome' => 'Greenwich Ortalama Saati (São Tomé)',
         'Africa/Tripoli' => 'Doğu Avrupa Saati (Trablus)',
         'Africa/Tunis' => 'Orta Avrupa Saati (Tunus)',
         'Africa/Windhoek' => 'Orta Afrika Saati (Windhoek)',
@@ -58,40 +59,46 @@ return [
         'America/Anchorage' => 'Alaska Saati (Anchorage)',
         'America/Anguilla' => 'Atlantik Saati (Anguilla)',
         'America/Antigua' => 'Atlantik Saati (Antigua)',
-        'America/Araguaina' => 'Brasilia Saati (Araguaina)',
+        'America/Araguaina' => 'Brasilia Saati (Araguaína)',
         'America/Argentina/La_Rioja' => 'Arjantin Saati (La Rioja)',
-        'America/Argentina/Rio_Gallegos' => 'Arjantin Saati (Rio Gallegos)',
+        'America/Argentina/Rio_Gallegos' => 'Arjantin Saati (Río Gallegos)',
         'America/Argentina/Salta' => 'Arjantin Saati (Salta)',
         'America/Argentina/San_Juan' => 'Arjantin Saati (San Juan)',
         'America/Argentina/San_Luis' => 'Arjantin Saati (San Luis)',
-        'America/Argentina/Tucuman' => 'Arjantin Saati (Tucuman)',
+        'America/Argentina/Tucuman' => 'Arjantin Saati (Tucumán)',
         'America/Argentina/Ushuaia' => 'Arjantin Saati (Ushuaia)',
         'America/Aruba' => 'Atlantik Saati (Aruba)',
         'America/Asuncion' => 'Paraguay Saati (Asunción)',
         'America/Bahia' => 'Brasilia Saati (Bahia)',
         'America/Bahia_Banderas' => 'Kuzey Amerika Merkezi Saati (Bahia Banderas)',
         'America/Barbados' => 'Atlantik Saati (Barbados)',
-        'America/Belem' => 'Brasilia Saati (Belem)',
+        'America/Belem' => 'Brasilia Saati (Belém)',
         'America/Belize' => 'Kuzey Amerika Merkezi Saati (Belize)',
         'America/Blanc-Sablon' => 'Atlantik Saati (Blanc-Sablon)',
         'America/Boa_Vista' => 'Amazon Saati (Boa Vista)',
-        'America/Bogota' => 'Kolombiya Saati (Bogota)',
+        'America/Bogota' => 'Kolombiya Saati (Bogotá)',
         'America/Boise' => 'Kuzey Amerika Dağ Saati (Boise)',
         'America/Buenos_Aires' => 'Arjantin Saati (Buenos Aires)',
+        'America/Argentina/Buenos_Aires' => 'Arjantin Saati (Buenos Aires)',
         'America/Cambridge_Bay' => 'Kuzey Amerika Dağ Saati (Cambridge Bay)',
         'America/Campo_Grande' => 'Amazon Saati (Campo Grande)',
         'America/Cancun' => 'Kuzey Amerika Doğu Saati (Cancun)',
         'America/Caracas' => 'Venezuela Saati (Caracas)',
         'America/Catamarca' => 'Arjantin Saati (Catamarca)',
+        'America/Argentina/Catamarca' => 'Arjantin Saati (Catamarca)',
         'America/Cayenne' => 'Fransız Guyanası Saati (Cayenne)',
         'America/Cayman' => 'Kuzey Amerika Doğu Saati (Cayman)',
         'America/Chicago' => 'Kuzey Amerika Merkezi Saati (Chicago)',
-        'America/Chihuahua' => 'Meksika Pasifik Kıyısı Saati (Chihuahua)',
+        'America/Chihuahua' => 'Kuzey Amerika Merkezi Saati (Chihuahua)',
+        'America/Ciudad_Juarez' => 'Kuzey Amerika Dağ Saati (Ciudad Juárez)',
         'America/Coral_Harbour' => 'Kuzey Amerika Doğu Saati (Atikokan)',
-        'America/Cordoba' => 'Arjantin Saati (Cordoba)',
+        'America/Atikokan' => 'Kuzey Amerika Doğu Saati (Atikokan)',
+        'America/Cordoba' => 'Arjantin Saati (Córdoba)',
+        'America/Argentina/Cordoba' => 'Arjantin Saati (Córdoba)',
         'America/Costa_Rica' => 'Kuzey Amerika Merkezi Saati (Kosta Rika)',
+        'America/Coyhaique' => 'Şili Saati (Coyhaique)',
         'America/Creston' => 'Kuzey Amerika Dağ Saati (Creston)',
-        'America/Cuiaba' => 'Amazon Saati (Cuiaba)',
+        'America/Cuiaba' => 'Amazon Saati (Cuiabá)',
         'America/Curacao' => 'Atlantik Saati (Curaçao)',
         'America/Danmarkshavn' => 'Greenwich Ortalama Saati (Danmarkshavn)',
         'America/Dawson' => 'Yukon Saati (Dawson)',
@@ -100,12 +107,13 @@ return [
         'America/Detroit' => 'Kuzey Amerika Doğu Saati (Detroit)',
         'America/Dominica' => 'Atlantik Saati (Dominika)',
         'America/Edmonton' => 'Kuzey Amerika Dağ Saati (Edmonton)',
-        'America/Eirunepe' => 'Acre Saati (Eirunepe)',
+        'America/Eirunepe' => 'Acre Saati (Eirunepé)',
         'America/El_Salvador' => 'Kuzey Amerika Merkezi Saati (El Salvador)',
         'America/Fort_Nelson' => 'Kuzey Amerika Dağ Saati (Fort Nelson)',
         'America/Fortaleza' => 'Brasilia Saati (Fortaleza)',
         'America/Glace_Bay' => 'Atlantik Saati (Glace Bay)',
-        'America/Godthab' => 'Batı Grönland Saati (Nuuk)',
+        'America/Godthab' => 'Grönland Saati (Nuuk)',
+        'America/Nuuk' => 'Grönland Saati (Nuuk)',
         'America/Goose_Bay' => 'Atlantik Saati (Goose Bay)',
         'America/Grand_Turk' => 'Kuzey Amerika Doğu Saati (Grand Turk)',
         'America/Grenada' => 'Atlantik Saati (Grenada)',
@@ -124,10 +132,12 @@ return [
         'America/Indiana/Vincennes' => 'Kuzey Amerika Doğu Saati (Vincennes, Indiana)',
         'America/Indiana/Winamac' => 'Kuzey Amerika Doğu Saati (Winamac, Indiana)',
         'America/Indianapolis' => 'Kuzey Amerika Doğu Saati (Indianapolis)',
+        'America/Indiana/Indianapolis' => 'Kuzey Amerika Doğu Saati (Indianapolis)',
         'America/Inuvik' => 'Kuzey Amerika Dağ Saati (Inuvik)',
         'America/Iqaluit' => 'Kuzey Amerika Doğu Saati (Iqaluit)',
         'America/Jamaica' => 'Kuzey Amerika Doğu Saati (Jamaika)',
         'America/Jujuy' => 'Arjantin Saati (Jujuy)',
+        'America/Argentina/Jujuy' => 'Arjantin Saati (Jujuy)',
         'America/Juneau' => 'Alaska Saati (Juneau)',
         'America/Kentucky/Monticello' => 'Kuzey Amerika Doğu Saati (Monticello, Kentucky)',
         'America/Kralendijk' => 'Atlantik Saati (Kralendijk)',
@@ -135,36 +145,35 @@ return [
         'America/Lima' => 'Peru Saati (Lima)',
         'America/Los_Angeles' => 'Kuzey Amerika Pasifik Saati (Los Angeles)',
         'America/Louisville' => 'Kuzey Amerika Doğu Saati (Louisville)',
+        'America/Kentucky/Louisville' => 'Kuzey Amerika Doğu Saati (Louisville)',
         'America/Lower_Princes' => 'Atlantik Saati (Lower Prince’s Quarter)',
-        'America/Maceio' => 'Brasilia Saati (Maceio)',
+        'America/Maceio' => 'Brasilia Saati (Maceió)',
         'America/Managua' => 'Kuzey Amerika Merkezi Saati (Managua)',
         'America/Manaus' => 'Amazon Saati (Manaus)',
         'America/Marigot' => 'Atlantik Saati (Marigot)',
         'America/Martinique' => 'Atlantik Saati (Martinique)',
         'America/Matamoros' => 'Kuzey Amerika Merkezi Saati (Matamoros)',
-        'America/Mazatlan' => 'Meksika Pasifik Kıyısı Saati (Mazatlan)',
+        'America/Mazatlan' => 'Meksika Pasifik Kıyısı Saati (Mazatlán)',
         'America/Mendoza' => 'Arjantin Saati (Mendoza)',
+        'America/Argentina/Mendoza' => 'Arjantin Saati (Mendoza)',
         'America/Menominee' => 'Kuzey Amerika Merkezi Saati (Menominee)',
         'America/Merida' => 'Kuzey Amerika Merkezi Saati (Merida)',
         'America/Metlakatla' => 'Alaska Saati (Metlakatla)',
-        'America/Mexico_City' => 'Kuzey Amerika Merkezi Saati (Mexico City)',
+        'America/Mexico_City' => 'Kuzey Amerika Merkezi Saati (Ciudad de México)',
         'America/Miquelon' => 'Saint Pierre ve Miquelon Saati',
         'America/Moncton' => 'Atlantik Saati (Moncton)',
         'America/Monterrey' => 'Kuzey Amerika Merkezi Saati (Monterrey)',
         'America/Montevideo' => 'Uruguay Saati (Montevideo)',
-        'America/Montreal' => 'Kanada Saati (Montreal)',
         'America/Montserrat' => 'Atlantik Saati (Montserrat)',
         'America/Nassau' => 'Kuzey Amerika Doğu Saati (Nassau)',
         'America/New_York' => 'Kuzey Amerika Doğu Saati (New York)',
-        'America/Nipigon' => 'Kuzey Amerika Doğu Saati (Nipigon)',
         'America/Nome' => 'Alaska Saati (Nome)',
         'America/Noronha' => 'Fernando de Noronha Saati',
         'America/North_Dakota/Beulah' => 'Kuzey Amerika Merkezi Saati (Beulah, Kuzey Dakota)',
         'America/North_Dakota/Center' => 'Kuzey Amerika Merkezi Saati (Merkez, Kuzey Dakota)',
         'America/North_Dakota/New_Salem' => 'Kuzey Amerika Merkezi Saati (New Salem, Kuzey Dakota)',
-        'America/Ojinaga' => 'Kuzey Amerika Dağ Saati (Ojinaga)',
+        'America/Ojinaga' => 'Kuzey Amerika Merkezi Saati (Ojinaga)',
         'America/Panama' => 'Kuzey Amerika Doğu Saati (Panama)',
-        'America/Pangnirtung' => 'Kuzey Amerika Doğu Saati (Pangnirtung)',
         'America/Paramaribo' => 'Surinam Saati (Paramaribo)',
         'America/Phoenix' => 'Kuzey Amerika Dağ Saati (Phoenix)',
         'America/Port-au-Prince' => 'Kuzey Amerika Doğu Saati (Port-au-Prince)',
@@ -172,18 +181,16 @@ return [
         'America/Porto_Velho' => 'Amazon Saati (Porto Velho)',
         'America/Puerto_Rico' => 'Atlantik Saati (Porto Riko)',
         'America/Punta_Arenas' => 'Şili Saati (Punta Arenas)',
-        'America/Rainy_River' => 'Kuzey Amerika Merkezi Saati (Rainy River)',
         'America/Rankin_Inlet' => 'Kuzey Amerika Merkezi Saati (Rankin Inlet)',
         'America/Recife' => 'Brasilia Saati (Recife)',
         'America/Regina' => 'Kuzey Amerika Merkezi Saati (Regina)',
         'America/Resolute' => 'Kuzey Amerika Merkezi Saati (Resolute)',
         'America/Rio_Branco' => 'Acre Saati (Rio Branco)',
-        'America/Santa_Isabel' => 'Kuzeybatı Meksika Saati (Santa Isabel)',
-        'America/Santarem' => 'Brasilia Saati (Santarem)',
+        'America/Santarem' => 'Brasilia Saati (Santarém)',
         'America/Santiago' => 'Şili Saati (Santiago)',
         'America/Santo_Domingo' => 'Atlantik Saati (Santo Domingo)',
-        'America/Sao_Paulo' => 'Brasilia Saati (Sao Paulo)',
-        'America/Scoresbysund' => 'Doğu Grönland Saati (Ittoqqortoormiit)',
+        'America/Sao_Paulo' => 'Brasilia Saati (São Paulo)',
+        'America/Scoresbysund' => 'Grönland Saati (Ittoqqortoormiit)',
         'America/Sitka' => 'Alaska Saati (Sitka)',
         'America/St_Barthelemy' => 'Atlantik Saati (Saint Barthelemy)',
         'America/St_Johns' => 'Newfoundland Saati (St. John’s)',
@@ -194,7 +201,6 @@ return [
         'America/Swift_Current' => 'Kuzey Amerika Merkezi Saati (Swift Current)',
         'America/Tegucigalpa' => 'Kuzey Amerika Merkezi Saati (Tegucigalpa)',
         'America/Thule' => 'Atlantik Saati (Thule)',
-        'America/Thunder_Bay' => 'Kuzey Amerika Doğu Saati (Thunder Bay)',
         'America/Tijuana' => 'Kuzey Amerika Pasifik Saati (Tijuana)',
         'America/Toronto' => 'Kuzey Amerika Doğu Saati (Toronto)',
         'America/Tortola' => 'Atlantik Saati (Tortola)',
@@ -202,8 +208,7 @@ return [
         'America/Whitehorse' => 'Yukon Saati (Whitehorse)',
         'America/Winnipeg' => 'Kuzey Amerika Merkezi Saati (Winnipeg)',
         'America/Yakutat' => 'Alaska Saati (Yakutat)',
-        'America/Yellowknife' => 'Kuzey Amerika Dağ Saati (Yellowknife)',
-        'Antarctica/Casey' => 'Casey Saati',
+        'Antarctica/Casey' => 'Batı Avustralya Saati (Casey)',
         'Antarctica/Davis' => 'Davis Saati',
         'Antarctica/DumontDUrville' => 'Dumont-d’Urville Saati',
         'Antarctica/Macquarie' => 'Doğu Avustralya Saati (Macquarie)',
@@ -216,24 +221,24 @@ return [
         'Antarctica/Vostok' => 'Vostok Saati',
         'Arctic/Longyearbyen' => 'Orta Avrupa Saati (Longyearbyen)',
         'Asia/Aden' => 'Arabistan Saati (Aden)',
-        'Asia/Almaty' => 'Doğu Kazakistan Saati (Almatı)',
+        'Asia/Almaty' => 'Kazakistan Saati (Almatı)',
         'Asia/Amman' => 'Doğu Avrupa Saati (Amman)',
-        'Asia/Anadyr' => 'Anadyr Saati (Anadır)',
-        'Asia/Aqtau' => 'Batı Kazakistan Saati (Aktav)',
-        'Asia/Aqtobe' => 'Batı Kazakistan Saati (Aktöbe)',
+        'Asia/Anadyr' => 'Petropavlovsk-Kamçatski Saati (Anadır)',
+        'Asia/Aqtau' => 'Kazakistan Saati (Aktav)',
+        'Asia/Aqtobe' => 'Kazakistan Saati (Aktöbe)',
         'Asia/Ashgabat' => 'Türkmenistan Saati (Aşkabat)',
-        'Asia/Atyrau' => 'Batı Kazakistan Saati (Atırav)',
+        'Asia/Atyrau' => 'Kazakistan Saati (Atırav)',
         'Asia/Baghdad' => 'Arabistan Saati (Bağdat)',
         'Asia/Bahrain' => 'Arabistan Saati (Bahreyn)',
         'Asia/Baku' => 'Azerbaycan Saati (Bakü)',
         'Asia/Bangkok' => 'Hindiçin Saati (Bangkok)',
-        'Asia/Barnaul' => 'Rusya Saati (Barnaul)',
+        'Asia/Barnaul' => 'Krasnoyarsk Saati (Barnaul)',
         'Asia/Beirut' => 'Doğu Avrupa Saati (Beyrut)',
         'Asia/Bishkek' => 'Kırgızistan Saati (Bişkek)',
         'Asia/Brunei' => 'Brunei Darü’s-Selam Saati',
         'Asia/Calcutta' => 'Hindistan Standart Saati (Kalküta)',
+        'Asia/Kolkata' => 'Hindistan Standart Saati (Kalküta)',
         'Asia/Chita' => 'Yakutsk Saati (Çita)',
-        'Asia/Choibalsan' => 'Ulan Batur Saati (Çoybalsan)',
         'Asia/Colombo' => 'Hindistan Standart Saati (Kolombo)',
         'Asia/Damascus' => 'Doğu Avrupa Saati (Şam)',
         'Asia/Dhaka' => 'Bangladeş Saati (Dakka)',
@@ -244,7 +249,7 @@ return [
         'Asia/Gaza' => 'Doğu Avrupa Saati (Gazze)',
         'Asia/Hebron' => 'Doğu Avrupa Saati (El Halil)',
         'Asia/Hong_Kong' => 'Hong Kong Saati',
-        'Asia/Hovd' => 'Hovd Saati',
+        'Asia/Hovd' => 'Hovd Saati (Khovd)',
         'Asia/Irkutsk' => 'İrkutsk Saati',
         'Asia/Jakarta' => 'Batı Endonezya Saati (Cakarta)',
         'Asia/Jayapura' => 'Doğu Endonezya Saati (Jayapura)',
@@ -253,6 +258,7 @@ return [
         'Asia/Kamchatka' => 'Petropavlovsk-Kamçatski Saati (Kamçatka)',
         'Asia/Karachi' => 'Pakistan Saati (Karaçi)',
         'Asia/Katmandu' => 'Nepal Saati (Katmandu)',
+        'Asia/Kathmandu' => 'Nepal Saati (Katmandu)',
         'Asia/Khandyga' => 'Yakutsk Saati (Handiga)',
         'Asia/Krasnoyarsk' => 'Krasnoyarsk Saati',
         'Asia/Kuala_Lumpur' => 'Malezya Saati (Kuala Lumpur)',
@@ -265,19 +271,21 @@ return [
         'Asia/Muscat' => 'Körfez Saati (Maskat)',
         'Asia/Nicosia' => 'Doğu Avrupa Saati (Lefkoşa)',
         'Asia/Novokuznetsk' => 'Krasnoyarsk Saati (Novokuznetsk)',
-        'Asia/Novosibirsk' => 'Novosibirsk Saati',
+        'Asia/Novosibirsk' => 'Krasnoyarsk Saati (Novosibirsk)',
         'Asia/Omsk' => 'Omsk Saati',
-        'Asia/Oral' => 'Batı Kazakistan Saati (Oral)',
+        'Asia/Oral' => 'Kazakistan Saati (Oral)',
         'Asia/Phnom_Penh' => 'Hindiçin Saati (Phnom Penh)',
         'Asia/Pontianak' => 'Batı Endonezya Saati (Pontianak)',
         'Asia/Pyongyang' => 'Kore Saati (Pyongyang)',
         'Asia/Qatar' => 'Arabistan Saati (Katar)',
-        'Asia/Qostanay' => 'Doğu Kazakistan Saati (Kostanay)',
-        'Asia/Qyzylorda' => 'Batı Kazakistan Saati (Kızılorda)',
+        'Asia/Qostanay' => 'Kazakistan Saati (Kostanay)',
+        'Asia/Qyzylorda' => 'Kazakistan Saati (Kızılorda)',
         'Asia/Rangoon' => 'Myanmar Saati (Yangon)',
+        'Asia/Yangon' => 'Myanmar Saati (Yangon)',
         'Asia/Riyadh' => 'Arabistan Saati (Riyad)',
         'Asia/Saigon' => 'Hindiçin Saati (Ho Chi Minh Kenti)',
-        'Asia/Sakhalin' => 'Sahalin Saati',
+        'Asia/Ho_Chi_Minh' => 'Hindiçin Saati (Ho Chi Minh Kenti)',
+        'Asia/Sakhalin' => 'Magadan Saati (Sahalin)',
         'Asia/Samarkand' => 'Özbekistan Saati (Semerkand)',
         'Asia/Seoul' => 'Kore Saati (Seul)',
         'Asia/Shanghai' => 'Çin Saati (Şanghay)',
@@ -289,7 +297,7 @@ return [
         'Asia/Tehran' => 'İran Saati (Tahran)',
         'Asia/Thimphu' => 'Butan Saati (Thimphu)',
         'Asia/Tokyo' => 'Japonya Saati (Tokyo)',
-        'Asia/Tomsk' => 'Rusya Saati (Tomsk)',
+        'Asia/Tomsk' => 'Krasnoyarsk Saati (Tomsk)',
         'Asia/Ulaanbaatar' => 'Ulan Batur Saati',
         'Asia/Urumqi' => 'Çin Saati (Urumçi)',
         'Asia/Ust-Nera' => 'Vladivostok Saati (Ust-Nera)',
@@ -303,6 +311,7 @@ return [
         'Atlantic/Canary' => 'Batı Avrupa Saati (Kanarya Adaları)',
         'Atlantic/Cape_Verde' => 'Cape Verde Saati',
         'Atlantic/Faeroe' => 'Batı Avrupa Saati (Faroe)',
+        'Atlantic/Faroe' => 'Batı Avrupa Saati (Faroe)',
         'Atlantic/Madeira' => 'Batı Avrupa Saati (Madeira Adaları)',
         'Atlantic/Reykjavik' => 'Greenwich Ortalama Saati (Reykjavik)',
         'Atlantic/South_Georgia' => 'Güney Georgia Saati',
@@ -311,7 +320,6 @@ return [
         'Australia/Adelaide' => 'Orta Avustralya Saati (Adelaide)',
         'Australia/Brisbane' => 'Doğu Avustralya Saati (Brisbane)',
         'Australia/Broken_Hill' => 'Orta Avustralya Saati (Broken Hill)',
-        'Australia/Currie' => 'Doğu Avustralya Saati (Currie)',
         'Australia/Darwin' => 'Orta Avustralya Saati (Darwin)',
         'Australia/Eucla' => 'İç Batı Avustralya Saati (Eucla)',
         'Australia/Hobart' => 'Doğu Avustralya Saati (Hobart)',
@@ -320,13 +328,11 @@ return [
         'Australia/Melbourne' => 'Doğu Avustralya Saati (Melbourne)',
         'Australia/Perth' => 'Batı Avustralya Saati (Perth)',
         'Australia/Sydney' => 'Doğu Avustralya Saati (Sidney)',
-        'CST6CDT' => 'Kuzey Amerika Merkezi Saati',
-        'EST5EDT' => 'Kuzey Amerika Doğu Saati',
         'Etc/GMT' => 'Greenwich Ortalama Saati',
         'Etc/UTC' => 'Eş Güdümlü Evrensel Zaman',
         'Europe/Amsterdam' => 'Orta Avrupa Saati (Amsterdam)',
         'Europe/Andorra' => 'Orta Avrupa Saati (Andorra)',
-        'Europe/Astrakhan' => 'Moskova Saati (Astrahan)',
+        'Europe/Astrakhan' => 'Samara Saati (Astrahan)',
         'Europe/Athens' => 'Doğu Avrupa Saati (Atina)',
         'Europe/Belgrade' => 'Orta Avrupa Saati (Belgrad)',
         'Europe/Berlin' => 'Orta Avrupa Saati (Berlin)',
@@ -337,7 +343,7 @@ return [
         'Europe/Busingen' => 'Orta Avrupa Saati (Büsingen)',
         'Europe/Chisinau' => 'Doğu Avrupa Saati (Kişinev)',
         'Europe/Copenhagen' => 'Orta Avrupa Saati (Kopenhag)',
-        'Europe/Dublin' => 'Greenwich Ortalama Saati (Dublin)',
+        'Europe/Dublin' => 'İrlanda Saati (Dublin)',
         'Europe/Gibraltar' => 'Orta Avrupa Saati (Cebelitarık)',
         'Europe/Guernsey' => 'Greenwich Ortalama Saati (Guernsey)',
         'Europe/Helsinki' => 'Doğu Avrupa Saati (Helsinki)',
@@ -346,7 +352,8 @@ return [
         'Europe/Jersey' => 'Greenwich Ortalama Saati (Jersey)',
         'Europe/Kaliningrad' => 'Doğu Avrupa Saati (Kaliningrad)',
         'Europe/Kiev' => 'Doğu Avrupa Saati (Kiev)',
-        'Europe/Kirov' => 'Rusya Saati (Kirov)',
+        'Europe/Kyiv' => 'Doğu Avrupa Saati (Kiev)',
+        'Europe/Kirov' => 'Moskova Saati (Kirov)',
         'Europe/Lisbon' => 'Batı Avrupa Saati (Lizbon)',
         'Europe/Ljubljana' => 'Orta Avrupa Saati (Ljubljana)',
         'Europe/London' => 'Greenwich Ortalama Saati (Londra)',
@@ -366,23 +373,21 @@ return [
         'Europe/Samara' => 'Samara Saati',
         'Europe/San_Marino' => 'Orta Avrupa Saati (San Marino)',
         'Europe/Sarajevo' => 'Orta Avrupa Saati (Saraybosna)',
-        'Europe/Saratov' => 'Moskova Saati (Saratov)',
+        'Europe/Saratov' => 'Samara Saati (Saratov)',
         'Europe/Simferopol' => 'Moskova Saati (Simferopol)',
         'Europe/Skopje' => 'Orta Avrupa Saati (Üsküp)',
         'Europe/Sofia' => 'Doğu Avrupa Saati (Sofya)',
         'Europe/Stockholm' => 'Orta Avrupa Saati (Stokholm)',
         'Europe/Tallinn' => 'Doğu Avrupa Saati (Tallinn)',
         'Europe/Tirane' => 'Orta Avrupa Saati (Tiran)',
-        'Europe/Ulyanovsk' => 'Moskova Saati (Ulyanovsk)',
-        'Europe/Uzhgorod' => 'Doğu Avrupa Saati (Ujgorod)',
+        'Europe/Ulyanovsk' => 'Samara Saati (Ulyanovsk)',
         'Europe/Vaduz' => 'Orta Avrupa Saati (Vaduz)',
         'Europe/Vatican' => 'Orta Avrupa Saati (Vatikan)',
         'Europe/Vienna' => 'Orta Avrupa Saati (Viyana)',
         'Europe/Vilnius' => 'Doğu Avrupa Saati (Vilnius)',
-        'Europe/Volgograd' => 'Volgograd Saati',
+        'Europe/Volgograd' => 'Moskova Saati (Volgograd)',
         'Europe/Warsaw' => 'Orta Avrupa Saati (Varşova)',
         'Europe/Zagreb' => 'Orta Avrupa Saati (Zagreb)',
-        'Europe/Zaporozhye' => 'Doğu Avrupa Saati (Zaporojye)',
         'Europe/Zurich' => 'Orta Avrupa Saati (Zürih)',
         'Indian/Antananarivo' => 'Doğu Afrika Saati (Antananarivo)',
         'Indian/Chagos' => 'Hint Okyanusu Saati (Chagos)',
@@ -390,29 +395,27 @@ return [
         'Indian/Cocos' => 'Cocos Adaları Saati',
         'Indian/Comoro' => 'Doğu Afrika Saati (Komor)',
         'Indian/Kerguelen' => 'Fransız Güney ve Antarktika Saati (Kerguelen)',
-        'Indian/Mahe' => 'Seyşeller Saati (Mahe)',
+        'Indian/Mahe' => 'Seyşeller Saati (Mahé)',
         'Indian/Maldives' => 'Maldivler Saati',
         'Indian/Mauritius' => 'Mauritius Saati',
         'Indian/Mayotte' => 'Doğu Afrika Saati (Mayotte)',
-        'Indian/Reunion' => 'Reunion Saati',
-        'MST7MDT' => 'Kuzey Amerika Dağ Saati',
-        'PST8PDT' => 'Kuzey Amerika Pasifik Saati',
+        'Indian/Reunion' => 'Reunion Saati (Réunion)',
         'Pacific/Apia' => 'Apia Saati',
         'Pacific/Auckland' => 'Yeni Zelanda Saati (Auckland)',
         'Pacific/Bougainville' => 'Papua Yeni Gine Saati (Bougainville)',
         'Pacific/Chatham' => 'Chatham Saati',
         'Pacific/Easter' => 'Paskalya Adası Saati',
         'Pacific/Efate' => 'Vanuatu Saati (Efate)',
-        'Pacific/Enderbury' => 'Phoenix Adaları Saati (Enderbury)',
+        'Pacific/Enderbury' => 'Phoenix Adaları Saati (Canton Adası)',
+        'Pacific/Kanton' => 'Phoenix Adaları Saati (Canton Adası)',
         'Pacific/Fakaofo' => 'Tokelau Saati (Fakaofo)',
         'Pacific/Fiji' => 'Fiji Saati',
         'Pacific/Funafuti' => 'Tuvalu Saati (Funafuti)',
-        'Pacific/Galapagos' => 'Galapagos Saati',
+        'Pacific/Galapagos' => 'Galapagos Saati (Galápagos)',
         'Pacific/Gambier' => 'Gambier Saati',
         'Pacific/Guadalcanal' => 'Solomon Adaları Saati (Guadalcanal)',
         'Pacific/Guam' => 'Chamorro Saati (Guam)',
-        'Pacific/Honolulu' => 'Hawaii-Aleut Saati (Honolulu)',
-        'Pacific/Johnston' => 'Hawaii-Aleut Saati (Johnston)',
+        'Pacific/Honolulu' => 'Hawaii-Aleut Standart Saati (Honolulu)',
         'Pacific/Kiritimati' => 'Line Adaları Saati (Kiritimati)',
         'Pacific/Kosrae' => 'Kosrae Saati',
         'Pacific/Kwajalein' => 'Marshall Adaları Saati (Kwajalein)',
@@ -422,11 +425,12 @@ return [
         'Pacific/Nauru' => 'Nauru Saati',
         'Pacific/Niue' => 'Niue Saati',
         'Pacific/Norfolk' => 'Norfolk Adası Saati',
-        'Pacific/Noumea' => 'Yeni Kaledonya Saati (Noumea)',
+        'Pacific/Noumea' => 'Yeni Kaledonya Saati (Nouméa)',
         'Pacific/Pago_Pago' => 'Samoa Saati (Pago Pago)',
         'Pacific/Palau' => 'Palau Saati',
         'Pacific/Pitcairn' => 'Pitcairn Saati',
         'Pacific/Ponape' => 'Ponape Saati (Pohnpei)',
+        'Pacific/Pohnpei' => 'Ponape Saati (Pohnpei)',
         'Pacific/Port_Moresby' => 'Papua Yeni Gine Saati (Port Moresby)',
         'Pacific/Rarotonga' => 'Cook Adaları Saati (Rarotonga)',
         'Pacific/Saipan' => 'Chamorro Saati (Saipan)',
@@ -434,9 +438,9 @@ return [
         'Pacific/Tarawa' => 'Gilbert Adaları Saati (Tarawa)',
         'Pacific/Tongatapu' => 'Tonga Saati (Tongatapu)',
         'Pacific/Truk' => 'Chuuk Saati',
+        'Pacific/Chuuk' => 'Chuuk Saati',
         'Pacific/Wake' => 'Wake Adası Saati',
-        'Pacific/Wallis' => 'Wallis ve Futuna Saati',
-    ],
-    'Meta' => [
+        'Pacific/Wallis' => 'Wallis ve Futuna Saati (Wallis & Futuna)',
     ],
+    'Meta' => [],
 ];
